@@ -1,4 +1,4 @@
-/* libctl: flexible Guile-based control files for scientific software 
+/* libctl: flexible Guile-based control files for scientific software
  * Copyright (C) 1998-2014 Massachusetts Institute of Technology and Steven G. Johnson
  *
  * This library is free software; you can redistribute it and/or
@@ -10,7 +10,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
@@ -21,6 +21,7 @@
 
 #include <stdlib.h>
 #include <string.h>
+#include <stddef.h>
 
 #include "ctl.h"
 #include "config.h"
@@ -40,7 +41,7 @@
    this, we require that Fortran callers pass us the length of a
    string as an explicit parameter.  We also have to include ugly
    hacks to accomodate the fact that Cray Fortran compilers pass
-   a data structure instead of a char* for string parameters. 
+   a data structure instead of a char* for string parameters.
 
    4) On some machines, C functions return their results in a way
    that the Fortran compiler can't handle.  To get around this,
@@ -178,10 +179,12 @@ void F77_FUNC(ctlgetstring,CTLGETSTRING)
 {
   char *r;
   char *s = fcp2ccp(identifier); s[*length] = 0;
+  int len;
   r = ctl_get_string(s);
   strncpy(fcp2ccp(result), r, *result_length);
-  if (*result_length < strlen(r))
-    *result_length = strlen(r);
+  len = (int) strlen(r);
+  if (*result_length < len)
+    *result_length = len;
   free(r);
 }
 
@@ -233,7 +236,7 @@ void F77_FUNC(ctlsetstring,CTLSETSTRING)
      (fortran_string identifier, int *length,
       fortran_string value, int *value_length)
 {
-  char *s = fcp2ccp(identifier); 
+  char *s = fcp2ccp(identifier);
   char *v = fcp2ccp(value);
   s[*length] = 0;
   v[*value_length] = 0;
@@ -289,10 +292,12 @@ void F77_FUNC(stringlistref,STRINGLISTREF)
      (list *l, int *index, fortran_string value, int *value_length)
 {
   char *v;
+  int len;
   v = string_list_ref(*l, *index);
   strncpy(fcp2ccp(value), v, *value_length);
-  if (*value_length < strlen(v))
-    *value_length = strlen(v);
+  len = (int) strlen(v);
+  if (*value_length < len)
+    *value_length = len;
   free(v);
 }
 
@@ -345,7 +350,7 @@ void F77_FUNC(makeobjectlist,MAKEOBJECTLIST)
 void F77_FUNC(objectismember,OBJECTISMEMBER)
      (fortran_string type_name, int *length, object *o, boolean *result)
 {
-  char *s = fcp2ccp(type_name); s[*length] = 0; 
+  char *s = fcp2ccp(type_name); s[*length] = 0;
   *result = object_is_member(s,*o);
 }
 
@@ -392,15 +397,17 @@ void F77_FUNC(objectobjectproperty,OBJECTOBJECTPROPERTY)
 }
 
 void F77_FUNC(stringobjectproperty,STRINGOBJECTPROPERTY)
-     (object *o, fortran_string property_name, int *length, 
+     (object *o, fortran_string property_name, int *length,
       fortran_string result, int *result_length)
 {
   char *r;
   char *s = fcp2ccp(property_name); s[*length] = 0;
+  int len;
   r = string_object_property(*o,s);
   strncpy(fcp2ccp(result), r, *result_length);
-  if (*result_length < strlen(r))
-    *result_length = strlen(r);
+  len = (int) strlen(r);
+  if (*result_length < len)
+    *result_length = len;
   free(r);
 }
 
