@@ -1,4 +1,4 @@
-/* libctl: flexible Guile-based control files for scientific software 
+/* libctl: flexible Guile-based control files for scientific software
  * Copyright (C) 1998-2014 Massachusetts Institute of Technology and Steven G. Johnson
  *
  * This library is free software; you can redistribute it and/or
@@ -10,7 +10,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
@@ -76,7 +76,7 @@ static SCM list_ref(list l, int index)
    from include.scm, or defaults to gh_load if this function isn't
    defined. */
 
-void ctl_include(char *filename)
+void ctl_include(const char *filename)
 {
   SCM include_proc = gh_lookup("include");
   if (include_proc == SCM_UNDEFINED)
@@ -97,7 +97,7 @@ char *ctl_fix_path(const char *path)
 	  SCM include_dir = gh_lookup("include-dir");
 	  if (include_dir != SCM_UNDEFINED) {
 	       char *dir = ctl_convert_string_to_c(include_dir);
-	       newpath = (char *) malloc(sizeof(char) * (strlen(dir) + 
+	       newpath = (char *) malloc(sizeof(char) * (strlen(dir) +
 							 strlen(path) + 2));
 	       strcpy(newpath, dir);
 	       free(dir);
@@ -114,292 +114,6 @@ char *ctl_fix_path(const char *path)
 
 /**************************************************************************/
 
-/* vector3 and matrix3x3 utilities: */
-
-number vector3_dot(vector3 v1,vector3 v2)
-{
-  return (v1.x * v2.x + v1.y * v2.y + v1.z * v2.z);
-}
-
-number vector3_norm(vector3 v)
-{
-  return (sqrt(vector3_dot(v,v)));
-}
-
-vector3 vector3_scale(number s, vector3 v)
-{
-  vector3 vnew;
-
-  vnew.x = s * v.x;
-  vnew.y = s * v.y;
-  vnew.z = s * v.z;
-  return vnew;
-}
-
-vector3 unit_vector3(vector3 v)
-{
-  number norm = vector3_norm(v);
-  if (norm == 0.0)
-    return v;
-  else
-    return vector3_scale(1.0/norm, v);
-}
-
-vector3 vector3_plus(vector3 v1,vector3 v2)
-{
-  vector3 vnew;
-
-  vnew.x = v1.x + v2.x;
-  vnew.y = v1.y + v2.y;
-  vnew.z = v1.z + v2.z;
-  return vnew;
-}
-
-vector3 vector3_minus(vector3 v1,vector3 v2)
-{
-  vector3 vnew;
-
-  vnew.x = v1.x - v2.x;
-  vnew.y = v1.y - v2.y;
-  vnew.z = v1.z - v2.z;
-  return vnew;
-}
-
-vector3 vector3_cross(vector3 v1,vector3 v2)
-{
-  vector3 vnew;
-
-  vnew.x = v1.y * v2.z - v2.y * v1.z;
-  vnew.y = v1.z * v2.x - v2.z * v1.x;
-  vnew.z = v1.x * v2.y - v2.x * v1.y;
-  return vnew;
-}
-
-int vector3_equal(vector3 v1, vector3 v2)
-{
-     return (v1.x == v2.x && v1.y == v2.y && v1.z == v2.z);
-}
-
-vector3 matrix3x3_vector3_mult(matrix3x3 m, vector3 v)
-{
-  vector3 vnew;
-
-  vnew.x = m.c0.x * v.x + m.c1.x * v.y + m.c2.x * v.z;
-  vnew.y = m.c0.y * v.x + m.c1.y * v.y + m.c2.y * v.z;
-  vnew.z = m.c0.z * v.x + m.c1.z * v.y + m.c2.z * v.z;
-  return vnew;
-}
-
-vector3 matrix3x3_transpose_vector3_mult(matrix3x3 m, vector3 v)
-{
-  vector3 vnew;
-
-  vnew.x = m.c0.x * v.x + m.c0.y * v.y + m.c0.z * v.z;
-  vnew.y = m.c1.x * v.x + m.c1.y * v.y + m.c1.z * v.z;
-  vnew.z = m.c2.x * v.x + m.c2.y * v.y + m.c2.z * v.z;
-  return vnew;
-}
-
-matrix3x3 matrix3x3_mult(matrix3x3 m1, matrix3x3 m2)
-{
-  matrix3x3 m;
-
-  m.c0.x = m1.c0.x * m2.c0.x + m1.c1.x * m2.c0.y + m1.c2.x * m2.c0.z;
-  m.c0.y = m1.c0.y * m2.c0.x + m1.c1.y * m2.c0.y + m1.c2.y * m2.c0.z;
-  m.c0.z = m1.c0.z * m2.c0.x + m1.c1.z * m2.c0.y + m1.c2.z * m2.c0.z;
-
-  m.c1.x = m1.c0.x * m2.c1.x + m1.c1.x * m2.c1.y + m1.c2.x * m2.c1.z;
-  m.c1.y = m1.c0.y * m2.c1.x + m1.c1.y * m2.c1.y + m1.c2.y * m2.c1.z;
-  m.c1.z = m1.c0.z * m2.c1.x + m1.c1.z * m2.c1.y + m1.c2.z * m2.c1.z;
-
-  m.c2.x = m1.c0.x * m2.c2.x + m1.c1.x * m2.c2.y + m1.c2.x * m2.c2.z;
-  m.c2.y = m1.c0.y * m2.c2.x + m1.c1.y * m2.c2.y + m1.c2.y * m2.c2.z;
-  m.c2.z = m1.c0.z * m2.c2.x + m1.c1.z * m2.c2.y + m1.c2.z * m2.c2.z;
-
-  return m;
-}
-
-matrix3x3 matrix3x3_transpose(matrix3x3 m)
-{
-     matrix3x3 mt;
-    
-     mt.c0.x = m.c0.x;
-     mt.c1.x = m.c0.y;
-     mt.c2.x = m.c0.z;
-     mt.c0.y = m.c1.x;
-     mt.c1.y = m.c1.y;
-     mt.c2.y = m.c1.z;
-     mt.c0.z = m.c2.x;
-     mt.c1.z = m.c2.y;
-     mt.c2.z = m.c2.z;
-     return mt;
-}
-
-number matrix3x3_determinant(matrix3x3 m)
-{
-     return(m.c0.x*m.c1.y*m.c2.z - m.c2.x*m.c1.y*m.c0.z +
-	    m.c1.x*m.c2.y*m.c0.z + m.c0.y*m.c1.z*m.c2.x -
-	    m.c1.x*m.c0.y*m.c2.z - m.c2.y*m.c1.z*m.c0.x);
-}
-
-matrix3x3 matrix3x3_inverse(matrix3x3 m)
-{
-     matrix3x3 minv;
-     number detinv = matrix3x3_determinant(m);
-
-     if (detinv == 0.0) {
-	  fprintf(stderr, "error: singular matrix in matrix3x3_inverse!\n");
-	  exit(EXIT_FAILURE);
-     }
-     detinv = 1.0/detinv;
-
-     minv.c0.x = detinv * (m.c1.y * m.c2.z - m.c2.y * m.c1.z);
-     minv.c1.y = detinv * (m.c0.x * m.c2.z - m.c2.x * m.c0.z);
-     minv.c2.z = detinv * (m.c1.y * m.c0.x - m.c0.y * m.c1.x);
-     
-     minv.c0.z = detinv * (m.c0.y * m.c1.z - m.c1.y * m.c0.z);
-     minv.c0.y = -detinv * (m.c0.y * m.c2.z - m.c2.y * m.c0.z);
-     minv.c1.z = -detinv * (m.c0.x * m.c1.z - m.c1.x * m.c0.z);
-     
-     minv.c2.x = detinv * (m.c1.x * m.c2.y - m.c1.y * m.c2.x);
-     minv.c1.x = -detinv * (m.c1.x * m.c2.z - m.c1.z * m.c2.x);
-     minv.c2.y = -detinv * (m.c0.x * m.c2.y - m.c0.y * m.c2.x);
-
-     return minv;
-}
-
-int matrix3x3_equal(matrix3x3 m1, matrix3x3 m2)
-{
-     return (vector3_equal(m1.c0, m2.c0)
-	     && vector3_equal(m1.c1, m2.c1)
-	     && vector3_equal(m1.c2, m2.c2));
-}
-
-vector3 matrix3x3_row1(matrix3x3 m)
-{
-     vector3 v;
-     v.x = m.c0.x;
-     v.y = m.c1.x;
-     v.z = m.c2.x;
-     return v;
-}
-
-vector3 matrix3x3_row2(matrix3x3 m)
-{
-     vector3 v;
-     v.x = m.c0.y;
-     v.y = m.c1.y;
-     v.z = m.c2.y;
-     return v;
-}
-
-vector3 matrix3x3_row3(matrix3x3 m)
-{
-     vector3 v;
-     v.x = m.c0.z;
-     v.y = m.c1.z;
-     v.z = m.c2.z;
-     return v;
-}
-
-/**************************************************************************/
-
-/* complex number utilities */
-
-cnumber make_cnumber(number r, number i)
-{
-     cnumber c;
-     c.re = r; c.im = i;
-     return c;
-}
-
-cnumber cnumber_conj(cnumber c)
-{
-     return make_cnumber(c.re, -c.im);
-}
-
-int cnumber_equal(cnumber c1, cnumber c2)
-{
-     return (c1.re == c2.re && c1.im == c2.im);
-}
-
-vector3 cvector3_re(cvector3 cv)
-{
-     vector3 v;
-     v.x = cv.x.re; v.y = cv.y.re; v.z = cv.z.re;
-     return v;
-}
-
-vector3 cvector3_im(cvector3 cv)
-{
-     vector3 v;
-     v.x = cv.x.im; v.y = cv.y.im; v.z = cv.z.im;
-     return v;
-}
-
-cvector3 make_cvector3(vector3 vr, vector3 vi)
-{
-     cvector3 cv;
-     cv.x = make_cnumber(vr.x, vi.x);
-     cv.y = make_cnumber(vr.y, vi.y);
-     cv.z = make_cnumber(vr.z, vi.z);
-     return cv;
-}
-
-int cvector3_equal(cvector3 v1, cvector3 v2)
-{
-     return (vector3_equal(cvector3_re(v1), cvector3_re(v2)) &&
-	     vector3_equal(cvector3_im(v1), cvector3_im(v2)));
-}
-
-matrix3x3 cmatrix3x3_re(cmatrix3x3 cm)
-{
-     matrix3x3 m;
-     m.c0 = cvector3_re(cm.c0);
-     m.c1 = cvector3_re(cm.c1);
-     m.c2 = cvector3_re(cm.c2);
-     return m;
-}
-
-matrix3x3 cmatrix3x3_im(cmatrix3x3 cm)
-{
-     matrix3x3 m;
-     m.c0 = cvector3_im(cm.c0);
-     m.c1 = cvector3_im(cm.c1);
-     m.c2 = cvector3_im(cm.c2);
-     return m;
-}
-
-cmatrix3x3 make_cmatrix3x3(matrix3x3 mr, matrix3x3 mi)
-{
-     cmatrix3x3 cm;
-     cm.c0 = make_cvector3(mr.c0, mi.c0);
-     cm.c1 = make_cvector3(mr.c1, mi.c1);
-     cm.c2 = make_cvector3(mr.c2, mi.c2);
-     return cm;
-}
-
-cmatrix3x3 make_hermitian_cmatrix3x3(number m00, number m11, number m22,
-				     cnumber m01, cnumber m02, cnumber m12)
-{
-     cmatrix3x3 cm;
-     cm.c0.x = make_cnumber(m00, 0);
-     cm.c1.y = make_cnumber(m11, 0);
-     cm.c2.z = make_cnumber(m22, 0);
-     cm.c1.x = m01; cm.c0.y = cnumber_conj(m01);
-     cm.c2.x = m02; cm.c0.z = cnumber_conj(m02);
-     cm.c2.y = m12; cm.c1.z = cnumber_conj(m12);
-     return cm;
-}
-
-int cmatrix3x3_equal(cmatrix3x3 m1, cmatrix3x3 m2)
-{
-     return (matrix3x3_equal(cmatrix3x3_re(m1), cmatrix3x3_re(m2)) &&
-	     matrix3x3_equal(cmatrix3x3_im(m1), cmatrix3x3_im(m2)));
-}
-
-/**************************************************************************/
-
 /* type conversion */
 
 vector3 scm2vector3(SCM sv)
@@ -445,7 +159,7 @@ static SCM make_vector3(SCM x, SCM y, SCM z)
 SCM vector32scm(vector3 v)
 {
   return make_vector3(ctl_convert_number_to_scm(v.x),
-		      ctl_convert_number_to_scm(v.y), 
+		      ctl_convert_number_to_scm(v.y),
 		      ctl_convert_number_to_scm(v.z));
 }
 
@@ -508,7 +222,7 @@ cmatrix3x3 scm2cmatrix3x3(SCM sm)
 SCM cvector32scm(cvector3 v)
 {
   return make_vector3(cnumber2scm(v.x),
-		      cnumber2scm(v.y), 
+		      cnumber2scm(v.y),
 		      cnumber2scm(v.z));
 }
 
@@ -525,67 +239,67 @@ SCM cmatrix3x32scm(cmatrix3x3 m)
 
 /**** Getters ****/
 
-integer ctl_get_integer(char *identifier)
+integer ctl_get_integer(const char *identifier)
 {
   return(ctl_convert_integer_to_c(gh_lookup(identifier)));
 }
 
-number ctl_get_number(char *identifier)
+number ctl_get_number(const char *identifier)
 {
   return(ctl_convert_number_to_c(gh_lookup(identifier)));
 }
 
-cnumber ctl_get_cnumber(char *identifier)
+cnumber ctl_get_cnumber(const char *identifier)
 {
   return(scm2cnumber(gh_lookup(identifier)));
 }
 
-boolean ctl_get_boolean(char *identifier)
+boolean ctl_get_boolean(const char *identifier)
 {
   return(ctl_convert_boolean_to_c(gh_lookup(identifier)));
 }
 
-char* ctl_get_string(char *identifier)
+char* ctl_get_string(const char *identifier)
 {
   return(ctl_convert_string_to_c(gh_lookup(identifier)));
 }
 
-vector3 ctl_get_vector3(char *identifier)
+vector3 ctl_get_vector3(const char *identifier)
 {
   return(scm2vector3(gh_lookup(identifier)));
 }
 
-matrix3x3 ctl_get_matrix3x3(char *identifier)
+matrix3x3 ctl_get_matrix3x3(const char *identifier)
 {
   return(scm2matrix3x3(gh_lookup(identifier)));
 }
 
-cvector3 ctl_get_cvector3(char *identifier)
+cvector3 ctl_get_cvector3(const char *identifier)
 {
   return(scm2cvector3(gh_lookup(identifier)));
 }
 
-cmatrix3x3 ctl_get_cmatrix3x3(char *identifier)
+cmatrix3x3 ctl_get_cmatrix3x3(const char *identifier)
 {
   return(scm2cmatrix3x3(gh_lookup(identifier)));
 }
 
-list ctl_get_list(char *identifier)
+list ctl_get_list(const char *identifier)
 {
   return(gh_lookup(identifier));
 }
 
-object ctl_get_object(char *identifier)
+object ctl_get_object(const char *identifier)
 {
   return(gh_lookup(identifier));
 }
 
-function ctl_get_function(char *identifier)
+function ctl_get_function(const char *identifier)
 {
   return(gh_lookup(identifier));
 }
 
-SCM ctl_get_SCM(char *identifier)
+SCM ctl_get_SCM(const char *identifier)
 {
   return(gh_lookup(identifier));
 }
@@ -606,9 +320,9 @@ SCM ctl_get_SCM(char *identifier)
    the correct module somehow; I also used this function to replace
    gh_lookup, which broke in Guile 1.3 as well...sigh.)
 
-   Note that I can't call "set!" because it is really a macro. 
+   Note that I can't call "set!" because it is really a macro.
 
-   All the ugliness is confined to the set_value() routine, though.  
+   All the ugliness is confined to the set_value() routine, though.
 
    Update: in Guile 1.5, we can call scm_variable_set_x (equivalent
    to variable-set!) to set values of variables, which are looked up
@@ -619,7 +333,7 @@ SCM ctl_get_SCM(char *identifier)
 #endif
 
 #ifdef USE_MY_SYMBOL_SET_X
-static SCM my_symbol_set_x(char *name, SCM v)
+static SCM my_symbol_set_x(const char *name, SCM v)
 {
      /* code swiped from scm_symbol_value0 and scm_symbol_set_x */
      SCM symbol = scm_intern_obarray_soft(name, strlen (name), scm_symhash, 0);
@@ -633,7 +347,7 @@ static SCM my_symbol_set_x(char *name, SCM v)
 }
 #endif
 
-static void set_value(char *identifier, SCM value)
+static void set_value(const char *identifier, SCM value)
 {
 #if defined(USE_SCM_SYMBOL_SET_X)   /* worked in Guile 1.1, 1.2 */
      scm_symbol_set_x(SCM_BOOL_F, gh_symbol2scm(identifier), value);
@@ -644,67 +358,67 @@ static void set_value(char *identifier, SCM value)
 #endif
 }
 
-void ctl_set_integer(char *identifier, integer value)
+void ctl_set_integer(const char *identifier, integer value)
 {
   set_value(identifier, ctl_convert_integer_to_scm(value));
 }
 
-void ctl_set_number(char *identifier, number value)
+void ctl_set_number(const char *identifier, number value)
 {
   set_value(identifier, ctl_convert_number_to_scm(value));
 }
 
-void ctl_set_cnumber(char *identifier, cnumber value)
+void ctl_set_cnumber(const char *identifier, cnumber value)
 {
   set_value(identifier, cnumber2scm(value));
 }
 
-void ctl_set_boolean(char *identifier, boolean value)
+void ctl_set_boolean(const char *identifier, boolean value)
 {
   set_value(identifier, ctl_convert_boolean_to_scm(value));
 }
 
-void ctl_set_string(char *identifier, char *value)
+void ctl_set_string(const char *identifier, const char *value)
 {
   set_value(identifier, ctl_convert_string_to_scm(value));
 }
 
-void ctl_set_vector3(char *identifier, vector3 value)
+void ctl_set_vector3(const char *identifier, vector3 value)
 {
   set_value(identifier, vector32scm(value));
 }
 
-void ctl_set_matrix3x3(char *identifier, matrix3x3 value)
+void ctl_set_matrix3x3(const char *identifier, matrix3x3 value)
 {
   set_value(identifier, matrix3x32scm(value));
 }
 
-void ctl_set_cvector3(char *identifier, cvector3 value)
+void ctl_set_cvector3(const char *identifier, cvector3 value)
 {
   set_value(identifier, cvector32scm(value));
 }
 
-void ctl_set_cmatrix3x3(char *identifier, cmatrix3x3 value)
+void ctl_set_cmatrix3x3(const char *identifier, cmatrix3x3 value)
 {
   set_value(identifier, cmatrix3x32scm(value));
 }
 
-void ctl_set_list(char *identifier, list value)
+void ctl_set_list(const char *identifier, list value)
 {
   set_value(identifier, value);
 }
 
-void ctl_set_object(char *identifier, object value)
+void ctl_set_object(const char *identifier, object value)
 {
   set_value(identifier, value);
 }
 
-void ctl_set_function(char *identifier, function value)
+void ctl_set_function(const char *identifier, function value)
 {
   set_value(identifier, value);
 }
 
-void ctl_set_SCM(char *identifier, SCM value)
+void ctl_set_SCM(const char *identifier, SCM value)
 {
   set_value(identifier, value);
 }
@@ -841,7 +555,7 @@ MAKE_LIST(cvector32scm)
 list make_cmatrix3x3_list(int num_items, const cmatrix3x3 *items)
 MAKE_LIST(cmatrix3x32scm)
 
-#define NO_CONVERSION  
+#define NO_CONVERSION
 
 list make_list_list(int num_items, const list *items)
 MAKE_LIST(NO_CONVERSION)
@@ -860,81 +574,81 @@ MAKE_LIST(NO_CONVERSION)
 
 /* object properties */
 
-boolean object_is_member(char *type_name, object o)
+boolean object_is_member(const char *type_name, object o)
 {
   return(SCM_BOOL_F != gh_call2(gh_lookup("object-member?"),
 				gh_symbol2scm(type_name),
 				o));
 }
 
-static SCM object_property_value(object o, char *property_name)
+static SCM object_property_value(object o, const char *property_name)
 {
   return(gh_call2(gh_lookup("object-property-value"),
-		  o, 
+		  o,
 		  gh_symbol2scm(property_name)));
 }
 
-integer integer_object_property(object o, char *property_name)
+integer integer_object_property(object o, const char *property_name)
 {
   return(ctl_convert_integer_to_c(object_property_value(o,property_name)));
 }
 
-number number_object_property(object o, char *property_name)
+number number_object_property(object o, const char *property_name)
 {
   return(ctl_convert_number_to_c(object_property_value(o,property_name)));
 }
 
-cnumber cnumber_object_property(object o, char *property_name)
+cnumber cnumber_object_property(object o, const char *property_name)
 {
   return(scm2cnumber(object_property_value(o,property_name)));
 }
 
-boolean boolean_object_property(object o, char *property_name)
+boolean boolean_object_property(object o, const char *property_name)
 {
   return(SCM_BOOL_F != object_property_value(o,property_name));
 }
 
-char* string_object_property(object o, char *property_name)
+char* string_object_property(object o, const char *property_name)
 {
   return(ctl_convert_string_to_c(object_property_value(o,property_name)));
 }
 
-vector3 vector3_object_property(object o, char *property_name)
+vector3 vector3_object_property(object o, const char *property_name)
 {
   return(scm2vector3(object_property_value(o,property_name)));
 }
 
-matrix3x3 matrix3x3_object_property(object o, char *property_name)
+matrix3x3 matrix3x3_object_property(object o, const char *property_name)
 {
   return(scm2matrix3x3(object_property_value(o,property_name)));
 }
 
-cvector3 cvector3_object_property(object o, char *property_name)
+cvector3 cvector3_object_property(object o, const char *property_name)
 {
   return(scm2cvector3(object_property_value(o,property_name)));
 }
 
-cmatrix3x3 cmatrix3x3_object_property(object o, char *property_name)
+cmatrix3x3 cmatrix3x3_object_property(object o, const char *property_name)
 {
   return(scm2cmatrix3x3(object_property_value(o,property_name)));
 }
 
-list list_object_property(object o, char *property_name)
+list list_object_property(object o, const char *property_name)
 {
   return(object_property_value(o,property_name));
 }
 
-object object_object_property(object o, char *property_name)
+object object_object_property(object o, const char *property_name)
 {
   return(object_property_value(o,property_name));
 }
 
-function function_object_property(object o, char *property_name)
+function function_object_property(object o, const char *property_name)
 {
   return(object_property_value(o,property_name));
 }
 
-SCM SCM_object_property(object o, char *property_name)
+SCM SCM_object_property(object o, const char *property_name)
 {
   return(object_property_value(o,property_name));
 }
