@@ -1,5 +1,5 @@
-; libctl: flexible Guile-based control files for scientific software 
-; Copyright (C) 1998-2012 Massachusetts Institute of Technology and Steven G. Johnson
+; libctl: flexible Guile-based control files for scientific software
+; Copyright (C) 1998-2014 Massachusetts Institute of Technology and Steven G. Johnson
 ;
 ; This library is free software; you can redistribute it and/or
 ; modify it under the terms of the GNU Lesser General Public
@@ -10,7 +10,7 @@
 ; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ; Lesser General Public License for more details.
-; 
+;
 ; You should have received a copy of the GNU Lesser General Public
 ; License along with this library; if not, write to the
 ; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
@@ -20,16 +20,9 @@
 
 ; ****************************************************************
 
-; hackery to define material-type if it is not defined, required by
-; the fact that Guile 2.x won't allow us to put define-class inside
-; an "if" statement.
-(define-class mt-hack no-parent
-  (define-property data no-default 'SCM)) ; generic user-defined data
-(set! class-list (cdr class-list)) ; delete mt-hack from list
-(set! mt-hack (cons 'material-type (cdr mt-hack))) ; rename to material-type
-(if (not (defined? 'material-type))
-    (set! class-list (cons mt-hack class-list)))
-(define material-type (if (defined? 'material-type) material-type mt-hack))
+(if (defined? 'ctl-io-c-only?) (set! ctl-io-c-only? true))
+
+(define MATERIAL-TYPE (if (defined? 'material-type) 'material-type 'SCM))
 
 ; A default material so that we don't have to specify a material for
 ; an object when we just care about its geometry.  If material-type is
@@ -37,13 +30,15 @@
 ; interpret this as equating to default-material (below).  However, we
 ; only define this default if (make material-type) works, i.e. if
 ; defaults exist for all properties (if any) of material-type.
-(define nothing (if (for-all? (class-properties-all material-type)
-			      property-has-default?)
-		    (make material-type)
-		    no-default))
+(define nothing (if (eq? MATERIAL-TYPE 'SCM)
+                    '()
+                    (if (for-all? (class-properties-all material-type)
+                                  property-has-default?)
+                        (make material-type)
+                        no-default)))
 
 (define-class geometric-object no-parent
-  (define-property material nothing 'material-type)
+  (define-property material nothing MATERIAL-TYPE)
   (define-property center no-default 'vector3))
 
 (define-class compound-geometric-object geometric-object
@@ -59,7 +54,7 @@
 
 (define-class cone cylinder
   (define-property radius2 0 'number))
-	       
+
 (define-class wedge cylinder
   (define-property wedge-angle (* 8 (atan 1)) 'number)
   (define-property wedge-start (vector3 1 0 0) 'vector3)
@@ -71,13 +66,12 @@
   (define-derived-property e2 'vector3
     (lambda (object)
       (let ((a (object-property-value object 'axis))
-	    (s (object-property-value object 'start))
 	    (e1 (object-property-value object 'e1)))
 	(vector3-cross a e1)))))
-	       
+
 (define-class sphere geometric-object
   (define-property radius no-default 'number non-negative?))
-	       
+
 (define-class block geometric-object
   (define-post-processed-property e1 (vector3 1 0 0) 'vector3 unit-vector3)
   (define-post-processed-property e2 (vector3 0 1 0) 'vector3 unit-vector3)
@@ -91,6 +85,18 @@
 	(object-property-value object 'e2)
 	(object-property-value object 'e3))))))
 
+(define identity_matrix (matrix3x3 (vector3 1 0 0) 
+                                   (vector3 0 1 0) 
+                                   (vector3 0 0 1)))
+
+(define-class prism geometric-object
+  (define-property vertices '() (make-list-type 'vector3))
+  (define-property centroid (vector3 0 0 0) 'vector3)
+  (define-property height 0 'number)
+  (define-property workspace '() (make-list-type 'number))
+  (define-property m_c2p identity_matrix 'matrix3x3)
+  (define-property m_p2c identity_matrix 'matrix3x3))
+
 (define-class ellipsoid block
   (define-derived-property inverse-semi-axes 'vector3
     (lambda (object)
@@ -167,7 +173,7 @@
 	(u2 (if (>= (length usize) 2) (list-ref usize 1) 1))
 	(u3 (if (>= (length usize) 3) (list-ref usize 2) 1))
 	(s (object-property-value lat 'size)))
-    (let ((b1 (lat->lattice (vector3 u1 0 0))) 
+    (let ((b1 (lat->lattice (vector3 u1 0 0)))
 	  (b2 (lat->lattice (vector3 0 u2 0)))
 	  (b3 (lat->lattice (vector3 0 0 u3)))
 	  (n1 (ceiling (/ (vector3-x s) u1)))
@@ -188,7 +194,7 @@
 ; ****************************************************************
 
 (define-input-var dimensions 3 'integer)
-(define-input-var default-material nothing 'material-type)
+(define-input-var default-material nothing MATERIAL-TYPE)
 (define-input-var geometry-center (vector3 0) 'vector3)
 (define-input-var geometry-lattice (make lattice) 'lattice)
 (define-input-var geometry '() (make-list-type 'geometric-object))
@@ -204,7 +210,7 @@
   'boolean 'vector3 'geometric-object)
 
 ; (define-external-function material-of-point true false
-;   'material-type 'vector3)
+;   MATERIAL-TYPE 'vector3)
 
 (define-external-function display-geometric-object-info false false
   no-return-value 'integer 'geometric-object)
@@ -246,8 +252,8 @@
   (if (vector3? x)
       (matrix3x3*
        (object-property-value geometry-lattice 'basis) x)
-      (matrix3x3* 
-       (matrix3x3* 
+      (matrix3x3*
+       (matrix3x3*
 	(object-property-value geometry-lattice 'basis) x)
        (matrix3x3-inverse (object-property-value geometry-lattice 'basis)))))
 
@@ -255,7 +261,7 @@
   (if (vector3? x)
       (matrix3x3*
        (matrix3x3-inverse (object-property-value geometry-lattice 'basis)) x)
-      (matrix3x3* 
+      (matrix3x3*
        (matrix3x3*
 	(matrix3x3-inverse (object-property-value geometry-lattice 'basis)) x)
        (object-property-value geometry-lattice 'basis))))
